@@ -6,20 +6,23 @@ Type annotations for ec2 service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_ec2.literals import AccountAttributeNameType
+    from mypy_boto3_ec2.literals import AcceleratorManufacturerType
 
-    data: AccountAttributeNameType = "default-vpc"
+    data: AcceleratorManufacturerType = "amazon-web-services"
     ```
 """
 import sys
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
 
 
 __all__ = (
+    "AcceleratorManufacturerType",
+    "AcceleratorNameType",
+    "AcceleratorTypeType",
     "AccountAttributeNameType",
     "ActivityStatusType",
     "AddressAttributeNameType",
@@ -39,12 +42,14 @@ __all__ = (
     "AutoPlacementType",
     "AvailabilityZoneOptInStatusType",
     "AvailabilityZoneStateType",
+    "BareMetalType",
     "BatchStateType",
     "BgpStatusType",
     "BootModeTypeType",
     "BootModeValuesType",
     "BundleTaskCompleteWaiterName",
     "BundleTaskStateType",
+    "BurstablePerformanceType",
     "ByoipCidrStateType",
     "CancelBatchErrorCodeType",
     "CancelSpotInstanceRequestStateType",
@@ -70,6 +75,7 @@ __all__ = (
     "ConversionTaskDeletedWaiterName",
     "ConversionTaskStateType",
     "CopyTagsFromSourceType",
+    "CpuManufacturerType",
     "CurrencyCodeValuesType",
     "CustomerGatewayAvailableWaiterName",
     "DatafeedSubscriptionStateType",
@@ -210,8 +216,10 @@ __all__ = (
     "GatewayTypeType",
     "GetAssociatedIpv6PoolCidrsPaginatorName",
     "GetGroupsForCapacityReservationPaginatorName",
+    "GetInstanceTypesFromInstanceRequirementsPaginatorName",
     "GetManagedPrefixListAssociationsPaginatorName",
     "GetManagedPrefixListEntriesPaginatorName",
+    "GetSpotPlacementScoresPaginatorName",
     "GetTransitGatewayAttachmentPropagationsPaginatorName",
     "GetTransitGatewayMulticastDomainAssociationsPaginatorName",
     "GetTransitGatewayPrefixListReferencesPaginatorName",
@@ -232,6 +240,7 @@ __all__ = (
     "InstanceAttributeNameType",
     "InstanceEventWindowStateType",
     "InstanceExistsWaiterName",
+    "InstanceGenerationType",
     "InstanceHealthStatusType",
     "InstanceInterruptionBehaviorType",
     "InstanceLifecycleType",
@@ -262,6 +271,8 @@ __all__ = (
     "ListingStatusType",
     "LocalGatewayRouteStateType",
     "LocalGatewayRouteTypeType",
+    "LocalStorageType",
+    "LocalStorageTypeType",
     "LocationTypeType",
     "LogDestinationTypeType",
     "MarketTypeType",
@@ -337,6 +348,7 @@ __all__ = (
     "SubnetStateType",
     "SummaryStatusType",
     "SystemStatusOkWaiterName",
+    "TargetCapacityUnitTypeType",
     "TelemetryStatusType",
     "TenancyType",
     "TrafficDirectionType",
@@ -398,6 +410,9 @@ __all__ = (
 )
 
 
+AcceleratorManufacturerType = Literal["amazon-web-services", "amd", "nvidia", "xilinx"]
+AcceleratorNameType = Literal["a100", "k80", "m60", "radeon-pro-v520", "t4", "v100", "vu9p"]
+AcceleratorTypeType = Literal["fpga", "gpu", "inference"]
 AccountAttributeNameType = Literal["default-vpc", "supported-platforms"]
 ActivityStatusType = Literal["error", "fulfilled", "pending_fulfillment", "pending_termination"]
 AddressAttributeNameType = Literal["domain-name"]
@@ -428,6 +443,7 @@ AutoAcceptSharedAttachmentsValueType = Literal["disable", "enable"]
 AutoPlacementType = Literal["off", "on"]
 AvailabilityZoneOptInStatusType = Literal["not-opted-in", "opt-in-not-required", "opted-in"]
 AvailabilityZoneStateType = Literal["available", "impaired", "information", "unavailable"]
+BareMetalType = Literal["excluded", "included", "required"]
 BatchStateType = Literal[
     "active",
     "cancelled",
@@ -444,6 +460,7 @@ BundleTaskCompleteWaiterName = Literal["bundle_task_complete"]
 BundleTaskStateType = Literal[
     "bundling", "cancelling", "complete", "failed", "pending", "storing", "waiting-for-shutdown"
 ]
+BurstablePerformanceType = Literal["excluded", "included", "required"]
 ByoipCidrStateType = Literal[
     "advertised",
     "deprovisioned",
@@ -509,6 +526,7 @@ ConversionTaskCompletedWaiterName = Literal["conversion_task_completed"]
 ConversionTaskDeletedWaiterName = Literal["conversion_task_deleted"]
 ConversionTaskStateType = Literal["active", "cancelled", "cancelling", "completed"]
 CopyTagsFromSourceType = Literal["volume"]
+CpuManufacturerType = Literal["amazon-web-services", "amd", "intel"]
 CurrencyCodeValuesType = Literal["USD"]
 CustomerGatewayAvailableWaiterName = Literal["customer_gateway_available"]
 DatafeedSubscriptionStateType = Literal["Active", "Inactive"]
@@ -697,8 +715,12 @@ FpgaImageStateCodeType = Literal["available", "failed", "pending", "unavailable"
 GatewayTypeType = Literal["ipsec.1"]
 GetAssociatedIpv6PoolCidrsPaginatorName = Literal["get_associated_ipv6_pool_cidrs"]
 GetGroupsForCapacityReservationPaginatorName = Literal["get_groups_for_capacity_reservation"]
+GetInstanceTypesFromInstanceRequirementsPaginatorName = Literal[
+    "get_instance_types_from_instance_requirements"
+]
 GetManagedPrefixListAssociationsPaginatorName = Literal["get_managed_prefix_list_associations"]
 GetManagedPrefixListEntriesPaginatorName = Literal["get_managed_prefix_list_entries"]
+GetSpotPlacementScoresPaginatorName = Literal["get_spot_placement_scores"]
 GetTransitGatewayAttachmentPropagationsPaginatorName = Literal[
     "get_transit_gateway_attachment_propagations"
 ]
@@ -758,6 +780,7 @@ InstanceAttributeNameType = Literal[
 ]
 InstanceEventWindowStateType = Literal["active", "creating", "deleted", "deleting"]
 InstanceExistsWaiterName = Literal["instance_exists"]
+InstanceGenerationType = Literal["current", "previous"]
 InstanceHealthStatusType = Literal["healthy", "unhealthy"]
 InstanceInterruptionBehaviorType = Literal["hibernate", "stop", "terminate"]
 InstanceLifecycleType = Literal["on-demand", "spot"]
@@ -879,6 +902,7 @@ InstanceTypeType = Literal[
     "d3en.6xlarge",
     "d3en.8xlarge",
     "d3en.xlarge",
+    "dl1.24xlarge",
     "f1.16xlarge",
     "f1.2xlarge",
     "f1.4xlarge",
@@ -1218,6 +1242,8 @@ ListingStateType = Literal["available", "cancelled", "pending", "sold"]
 ListingStatusType = Literal["active", "cancelled", "closed", "pending"]
 LocalGatewayRouteStateType = Literal["active", "blackhole", "deleted", "deleting", "pending"]
 LocalGatewayRouteTypeType = Literal["propagated", "static"]
+LocalStorageType = Literal["excluded", "included", "required"]
+LocalStorageTypeType = Literal["hdd", "ssd"]
 LocationTypeType = Literal["availability-zone", "availability-zone-id", "region"]
 LogDestinationTypeType = Literal["cloud-watch-logs", "s3"]
 MarketTypeType = Literal["spot"]
@@ -1409,6 +1435,7 @@ SubnetCidrReservationTypeType = Literal["explicit", "prefix"]
 SubnetStateType = Literal["available", "pending"]
 SummaryStatusType = Literal["impaired", "initializing", "insufficient-data", "not-applicable", "ok"]
 SystemStatusOkWaiterName = Literal["system_status_ok"]
+TargetCapacityUnitTypeType = Literal["memory-mib", "units", "vcpu"]
 TelemetryStatusType = Literal["DOWN", "UP"]
 TenancyType = Literal["dedicated", "default", "host"]
 TrafficDirectionType = Literal["egress", "ingress"]
@@ -1894,8 +1921,10 @@ PaginatorName = Literal[
     "describe_vpcs",
     "get_associated_ipv6_pool_cidrs",
     "get_groups_for_capacity_reservation",
+    "get_instance_types_from_instance_requirements",
     "get_managed_prefix_list_associations",
     "get_managed_prefix_list_entries",
+    "get_spot_placement_scores",
     "get_transit_gateway_attachment_propagations",
     "get_transit_gateway_multicast_domain_associations",
     "get_transit_gateway_prefix_list_references",
